#[repr(transparent)]pub struct Trig0Ctrl(pub u32);Expand description
ETC_TRIG Control Register
Tuple Fields
0: u32Implementations
Sourceimpl Trig0Ctrl
impl Trig0Ctrl
Sourcepub const fn sw_trig(&self) -> Trig0CtrlSwTrig
pub const fn sw_trig(&self) -> Trig0CtrlSwTrig
Software trigger. This field is self-clearing.
Sourcepub const fn set_sw_trig(&mut self, val: Trig0CtrlSwTrig)
pub const fn set_sw_trig(&mut self, val: Trig0CtrlSwTrig)
Software trigger. This field is self-clearing.
Sourcepub const fn trig_mode(&self) -> Trig0CtrlTrigMode
pub const fn trig_mode(&self) -> Trig0CtrlTrigMode
Trigger mode selection.
Sourcepub const fn set_trig_mode(&mut self, val: Trig0CtrlTrigMode)
pub const fn set_trig_mode(&mut self, val: Trig0CtrlTrigMode)
Trigger mode selection.
Sourcepub const fn trig_chain(&self) -> Trig0CtrlTrigChain
pub const fn trig_chain(&self) -> Trig0CtrlTrigChain
The number of segments inside the trigger chain of TRIGa.
Sourcepub const fn set_trig_chain(&mut self, val: Trig0CtrlTrigChain)
pub const fn set_trig_chain(&mut self, val: Trig0CtrlTrigChain)
The number of segments inside the trigger chain of TRIGa.
Sourcepub const fn trig_priority(&self) -> u8
pub const fn trig_priority(&self) -> u8
External trigger priority, 7 is highest priority, while 0 is lowest
Sourcepub const fn set_trig_priority(&mut self, val: u8)
pub const fn set_trig_priority(&mut self, val: u8)
External trigger priority, 7 is highest priority, while 0 is lowest
Sourcepub const fn sync_mode(&self) -> Trig0CtrlSyncMode
pub const fn sync_mode(&self) -> Trig0CtrlSyncMode
Trigger synchronization mode selection
Sourcepub const fn set_sync_mode(&mut self, val: Trig0CtrlSyncMode)
pub const fn set_sync_mode(&mut self, val: Trig0CtrlSyncMode)
Trigger synchronization mode selection