#[repr(transparent)]pub struct Trig3Ctrl(pub u32);Expand description
ETC_TRIG Control Register
Tuple Fields
0: u32Implementations
Sourceimpl Trig3Ctrl
impl Trig3Ctrl
Sourcepub const fn sw_trig(&self) -> Trig3CtrlSwTrig
pub const fn sw_trig(&self) -> Trig3CtrlSwTrig
Software trigger. This field is self-clearing.
Sourcepub const fn set_sw_trig(&mut self, val: Trig3CtrlSwTrig)
pub const fn set_sw_trig(&mut self, val: Trig3CtrlSwTrig)
Software trigger. This field is self-clearing.
Sourcepub const fn trig_mode(&self) -> Trig3CtrlTrigMode
pub const fn trig_mode(&self) -> Trig3CtrlTrigMode
Trigger mode selection.
Sourcepub const fn set_trig_mode(&mut self, val: Trig3CtrlTrigMode)
pub const fn set_trig_mode(&mut self, val: Trig3CtrlTrigMode)
Trigger mode selection.
Sourcepub const fn trig_chain(&self) -> Trig3CtrlTrigChain
pub const fn trig_chain(&self) -> Trig3CtrlTrigChain
The number of segments inside the trigger chain of TRIGa.
Sourcepub const fn set_trig_chain(&mut self, val: Trig3CtrlTrigChain)
pub const fn set_trig_chain(&mut self, val: Trig3CtrlTrigChain)
The number of segments inside the trigger chain of TRIGa.
Sourcepub const fn trig_priority(&self) -> u8
pub const fn trig_priority(&self) -> u8
External trigger priority, 7 is highest priority, while 0 is lowest
Sourcepub const fn set_trig_priority(&mut self, val: u8)
pub const fn set_trig_priority(&mut self, val: u8)
External trigger priority, 7 is highest priority, while 0 is lowest
Sourcepub const fn sync_mode(&self) -> Trig3CtrlSyncMode
pub const fn sync_mode(&self) -> Trig3CtrlSyncMode
Trigger synchronization mode selection
Sourcepub const fn set_sync_mode(&mut self, val: Trig3CtrlSyncMode)
pub const fn set_sync_mode(&mut self, val: Trig3CtrlSyncMode)
Trigger synchronization mode selection