#[repr(transparent)]pub struct Trig6Ctrl(pub u32);Expand description
ETC_TRIG Control Register
Tuple Fields
0: u32Implementations
Sourceimpl Trig6Ctrl
impl Trig6Ctrl
Sourcepub const fn sw_trig(&self) -> Trig6CtrlSwTrig
pub const fn sw_trig(&self) -> Trig6CtrlSwTrig
Software trigger. This field is self-clearing.
Sourcepub const fn set_sw_trig(&mut self, val: Trig6CtrlSwTrig)
pub const fn set_sw_trig(&mut self, val: Trig6CtrlSwTrig)
Software trigger. This field is self-clearing.
Sourcepub const fn trig_mode(&self) -> Trig6CtrlTrigMode
pub const fn trig_mode(&self) -> Trig6CtrlTrigMode
Trigger mode selection.
Sourcepub const fn set_trig_mode(&mut self, val: Trig6CtrlTrigMode)
pub const fn set_trig_mode(&mut self, val: Trig6CtrlTrigMode)
Trigger mode selection.
Sourcepub const fn trig_chain(&self) -> Trig6CtrlTrigChain
pub const fn trig_chain(&self) -> Trig6CtrlTrigChain
The number of segments inside the trigger chain of TRIGa.
Sourcepub const fn set_trig_chain(&mut self, val: Trig6CtrlTrigChain)
pub const fn set_trig_chain(&mut self, val: Trig6CtrlTrigChain)
The number of segments inside the trigger chain of TRIGa.
Sourcepub const fn trig_priority(&self) -> u8
pub const fn trig_priority(&self) -> u8
External trigger priority, 7 is highest priority, while 0 is lowest
Sourcepub const fn set_trig_priority(&mut self, val: u8)
pub const fn set_trig_priority(&mut self, val: u8)
External trigger priority, 7 is highest priority, while 0 is lowest
Sourcepub const fn sync_mode(&self) -> Trig6CtrlSyncMode
pub const fn sync_mode(&self) -> Trig6CtrlSyncMode
Trigger synchronization mode selection
Sourcepub const fn set_sync_mode(&mut self, val: Trig6CtrlSyncMode)
pub const fn set_sync_mode(&mut self, val: Trig6CtrlSyncMode)
Trigger synchronization mode selection