#[repr(transparent)]pub struct Trig4Ctrl(pub u32);Expand description
ETC_TRIG Control Register
Tuple Fields
0: u32Implementations
Sourceimpl Trig4Ctrl
impl Trig4Ctrl
Sourcepub const fn sw_trig(&self) -> Trig4CtrlSwTrig
pub const fn sw_trig(&self) -> Trig4CtrlSwTrig
Software trigger. This field is self-clearing.
Sourcepub const fn set_sw_trig(&mut self, val: Trig4CtrlSwTrig)
pub const fn set_sw_trig(&mut self, val: Trig4CtrlSwTrig)
Software trigger. This field is self-clearing.
Sourcepub const fn trig_mode(&self) -> Trig4CtrlTrigMode
pub const fn trig_mode(&self) -> Trig4CtrlTrigMode
Trigger mode selection.
Sourcepub const fn set_trig_mode(&mut self, val: Trig4CtrlTrigMode)
pub const fn set_trig_mode(&mut self, val: Trig4CtrlTrigMode)
Trigger mode selection.
Sourcepub const fn trig_chain(&self) -> Trig4CtrlTrigChain
pub const fn trig_chain(&self) -> Trig4CtrlTrigChain
The number of segments inside the trigger chain of TRIGa.
Sourcepub const fn set_trig_chain(&mut self, val: Trig4CtrlTrigChain)
pub const fn set_trig_chain(&mut self, val: Trig4CtrlTrigChain)
The number of segments inside the trigger chain of TRIGa.
Sourcepub const fn trig_priority(&self) -> u8
pub const fn trig_priority(&self) -> u8
External trigger priority, 7 is highest priority, while 0 is lowest
Sourcepub const fn set_trig_priority(&mut self, val: u8)
pub const fn set_trig_priority(&mut self, val: u8)
External trigger priority, 7 is highest priority, while 0 is lowest
Sourcepub const fn sync_mode(&self) -> Trig4CtrlSyncMode
pub const fn sync_mode(&self) -> Trig4CtrlSyncMode
Trigger synchronization mode selection
Sourcepub const fn set_sync_mode(&mut self, val: Trig4CtrlSyncMode)
pub const fn set_sync_mode(&mut self, val: Trig4CtrlSyncMode)
Trigger synchronization mode selection